==> haskell-x11-1.8-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x11.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11
version: 1.8
id: X11-1.8-JnAOOA5ca1mBqz6w5LwuYT
key: X11-1.8-JnAOOA5ca1mBqz6w5LwuYT
license: BSD3
copyright: Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007, Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.
maintainer: Daniel Wagner <daniel@wagner-home.com>
homepage: https://github.com/xmonad/X11
synopsis: A binding to the X11 graphics library
description:
    A Haskell binding to the X11 graphics library.
    The binding is a direct translation of the C binding; for
    documentation of these calls, refer to "The Xlib Programming
    Manual", available online at <http://tronche.com/gui/x/xlib/>.
category: Graphics
exposed: True
indefinite: False
exposed-modules:
    Graphics.X11 Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
    Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
    Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
    Graphics.X11.ExtraTypes.XorgDefault Graphics.X11.Types
    Graphics.X11.XScreenSaver Graphics.X11.Xinerama Graphics.X11.Xlib
    Graphics.X11.Xlib.Atom Graphics.X11.Xlib.Color
    Graphics.X11.Xlib.Context Graphics.X11.Xlib.Cursor
    Graphics.X11.Xlib.Display Graphics.X11.Xlib.Event
    Graphics.X11.Xlib.Extras Graphics.X11.Xlib.Font
    Graphics.X11.Xlib.Image Graphics.X11.Xlib.Misc
    Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
    Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
    Graphics.X11.Xrandr
hidden-modules: Graphics.X11.Xlib.Internal
abi: dd1e099e70ee20f9e445a96191644a34
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/X11-1.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/X11-1.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/X11-1.8
hs-libraries: HSX11-1.8-JnAOOA5ca1mBqz6w5LwuYT
extra-libraries:
    Xinerama Xext X11 Xrandr Xext
include-dirs: /usr/lib/ghc-8.2.2/site-local/X11-1.8/include
includes:
    HsXlib.h HsAllKeysyms.h
depends:
    base-4.10.1.0 data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=137eb1e83962885e435b3b188565ce6c
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces: /usr/share/doc/haskell-x11/html/X11.haddock
haddock-html: /usr/share/doc/haskell-x11/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x11-1.8-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x11.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11
version: 1.8
id: X11-1.8-elVOfhEBaVA43a4pLnRhy
key: X11-1.8-elVOfhEBaVA43a4pLnRhy
license: BSD-3-Clause
copyright: Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007, Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.
maintainer: Daniel Wagner <daniel@wagner-home.com>
homepage: https://github.com/xmonad/X11
synopsis: A binding to the X11 graphics library
description:
    A Haskell binding to the X11 graphics library.
    The binding is a direct translation of the C binding; for
    documentation of these calls, refer to "The Xlib Programming
    Manual", available online at <http://tronche.com/gui/x/xlib/>.
category: Graphics
abi: f642ebcb303cf0dee1e041f8bb46c075
exposed: True
exposed-modules:
    Graphics.X11 Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
    Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
    Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
    Graphics.X11.ExtraTypes.XorgDefault Graphics.X11.Types
    Graphics.X11.XScreenSaver Graphics.X11.Xinerama Graphics.X11.Xlib
    Graphics.X11.Xlib.Atom Graphics.X11.Xlib.Color
    Graphics.X11.Xlib.Context Graphics.X11.Xlib.Cursor
    Graphics.X11.Xlib.Display Graphics.X11.Xlib.Event
    Graphics.X11.Xlib.Extras Graphics.X11.Xlib.Font
    Graphics.X11.Xlib.Image Graphics.X11.Xlib.Misc
    Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
    Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
    Graphics.X11.Xrandr
hidden-modules: Graphics.X11.Xlib.Internal
import-dirs: /usr/lib/ghc-8.4.2/site-local/X11-1.8
library-dirs: /usr/lib/ghc-8.4.2/site-local/X11-1.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/X11-1.8
hs-libraries: HSX11-1.8-elVOfhEBaVA43a4pLnRhy
extra-libraries:
    Xinerama Xext X11 Xrandr Xext
include-dirs: /usr/lib/ghc-8.4.2/site-local/X11-1.8/include
includes:
    HsXlib.h HsAllKeysyms.h
depends:
    base-4.11.1.0 data-default-0.7.1.1-AgTeWrkyxxNC6ynssxrin9
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             data-default-0.7.1.1-AgTeWrkyxxNC6ynssxrin9=a4979222a15950c9d2bd2e5b3bc3a17a
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces: /usr/share/doc/haskell-x11/html/X11.haddock
haddock-html: /usr/share/doc/haskell-x11/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
